import React from "react";
import PropTypes from "prop-types";

import {
  Dialog,
  Button,
  Backdrop, DialogActions, DialogContent, List, ListItem, DialogTitle, ListItemText, ListItemIcon,
} from "@material-ui/core";

import "./ResultMetadataDialog.scss";
import {Typography} from "@material-ui/core";

export const ResultMetadataDialog = ({
  institutionName,
  open,
  onClose,
  resultMetadata,
}) => {
  return (
    <Dialog className="ResultMetadataDialog" open={open} onClose={onClose}>
      <div className="DialogContent">
        <span className="close-button" onClick={onClose} role="button">
          <i className="fa fa-times" aria-hidden="true" />
        </span>
        <div className="title-label-wrapper">
          <Typography className="title">{institutionName} - Metadata</Typography>
        </div>
        { resultMetadata.obfuscatingParameters &&
          <List>
            <div className={"list-title"}>Obfuscation settings</div>
            <ListItem>
              <List>
                {
                  Object.entries(resultMetadata.obfuscatingParameters).map(([key, value]) => {
                    return (
                      <ListItem>
                        <i className="fa-solid fa-minus list-icon" aria-hidden="true"/>
                        {key + " : " + value}
                      </ListItem>
                    );
                  })
                }
              </List>
            </ListItem>
          </List>
        }
        { resultMetadata.custom &&
          <List>
            {
              Object.entries(resultMetadata.custom).map(([key, value]) => {
                return (
                  <ListItem>
                    <ListItem>
                      <i className="fa-solid fa-minus" aria-hidden="true"/>
                      {key + " : " + value}
                    </ListItem>
                  </ListItem>
                );
              })
            }
          < /List>
        }
        <div className="button-row">
          <Button
            onClick={onClose}
            className="btn-primary submit-button"
          >
            Close
          </Button>
        </div>
      </div>
    </Dialog>
  );
};

ResultMetadataDialog.propTypes = {
  open: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  resultMetadata: PropTypes.object.isRequired,
};
